@@ -74,7 +74,7 @@ class Table(TableBase):
         for aggregation_dict in aggregation_dicts:
             aggregation_dict = DictCaster(
                 Item("attribute", cls.column_from_str),
-                Item("function", AggregationFunctionType),
+                Item("function", AggregationFunctionType, rename="function_type"),
             ).cast(aggregation_dict)
             aggregation_functions.append(AggregationFunction(**aggregation_dict))
         return aggregation_functions
